@@ -86,7 +86,7 @@ from . import adapter_bloodtiesfancom
 from . import adapter_qafficcom
 from . import adapter_efpfanficnet
 from . import adapter_potterficscom
-from . import adapter_efictionestelielde
+from . import adapter_faeriearchivecom
 from . import adapter_imagineeficcom
 from . import adapter_potterheadsanonymouscom
 from . import adapter_fictionpadcom
@@ -169,6 +169,7 @@ from . import adapter_fanficsme
 from . import adapter_archivehpfanfictalkcom
 from . import adapter_scifistoriescom
 from . import adapter_silmarillionwritersguildorg
+from . import adapter_chireadscom
 
 ## This bit of complexity allows adapters to be added by just adding
 ## importing.  It eliminates the long if/else clauses we used to need
