@@ -44,8 +44,10 @@ class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
         self.username = "NoneGiven" # if left empty, site doesn't return any message at all.
         self.password = ""
         self.is_adult=False
+        self.addurl = ""
 
         self.full_work_soup = None
+        self.full_work_chapters = None
         self.use_full_work_soup = True
 
         # get storyId from url--url validation guarantees query is only sid=1234
@@ -77,7 +79,14 @@ class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
 
     @classmethod
     def getAcceptDomains(cls):
-        return ['archiveofourown.org','archiveofourown.com','download.archiveofourown.org','download.archiveofourown.com']
+        return ['archiveofourown.org',
+                'archiveofourown.com',
+                'archiveofourown.net',
+                'download.archiveofourown.org',
+                'download.archiveofourown.com',
+                'download.archiveofourown.net',
+                'ao3.org',
+                ]
 
     @classmethod
     def getSiteExampleURLs(cls):
@@ -86,7 +95,15 @@ class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
     def getSiteURLPattern(self):
         # https://archiveofourown.org/collections/Smallville_Slash_Archive/works/159770
         # Discard leading zeros from story ID numbers--AO3 doesn't use them in it's own chapter URLs.
-        return r"https?://(download\.)?archiveofourown\.(org|com)(/collections/[^/]+)?/works/0*(?P<id>\d+)"
+        # logger.debug(r"https?://" + r"|".join([x.replace('.','\.') for x in self.getAcceptDomains()]) + r"(/collections/[^/]+)?/works/0*(?P<id>\d+)")
+        return r"https?://(" + r"|".join([x.replace('.','\.') for x in self.getAcceptDomains()]) + r")(/collections/[^/]+)?/works/0*(?P<id>\d+)"
+
+    # The certificate is only valid for the following names:
+    # ao3.org,
+    # archiveofourown.com,
+    # archiveofourown.net,
+    # archiveofourown.org,
+    # www.ao3.org,
 
     ## Login
     def needToLoginCheck(self, data):
@@ -138,12 +155,12 @@ class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
     def extractChapterUrlsAndMetadata(self):
 
         if self.is_adult or self.getConfig("is_adult"):
-            addurl = "?view_adult=true"
+            self.addurl = "?view_adult=true"
         else:
-            addurl=""
+            self.addurl=""
 
-        metaurl = self.url+addurl
-        url = self.url+'/navigate'+addurl
+        metaurl = self.url+self.addurl
+        url = self.url+'/navigate'+self.addurl
         logger.info("url: "+url)
         logger.info("metaurl: "+metaurl)
 
@@ -152,7 +169,15 @@ class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
             meta = self._fetchUrl(metaurl)
 
             if "This work could have adult content. If you proceed you have agreed that you are willing to see such content." in meta:
-                raise exceptions.AdultCheckRequired(self.url)
+                if self.addurl:
+                    ## "?view_adult=true" doesn't work on base story
+                    ## URL anymore, which means we have to
+                    metasoup = self.make_soup(meta)
+                    a = metasoup.find('a',text='Proceed')
+                    metaurl = 'https://'+self.host+a['href']
+                    meta = self._fetchUrl(metaurl)
+                else:
+                    raise exceptions.AdultCheckRequired(self.url)
 
         except HTTPError as e:
             if e.code == 404:
@@ -406,15 +431,24 @@ class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
             logger.debug("USE view_full_work")
             ## Assumed view_adult=true was cookied during metadata
             if not self.full_work_soup:
-                self.full_work_soup = self.make_soup(self._fetchUrl(self.url+"?view_full_work=true"))
-
+                self.full_work_soup = self.make_soup(self._fetchUrl(self.url+"?view_full_work=true"+self.addurl.replace('?','&')))
+                ## AO3 has had several cases now where chapter numbers
+                ## are missing, breaking the link between
+                ## <div id=chapter-##> and Chapter ##.
+                ## But they should all still be there and in the right
+                ## order, so array[index]
+                self.full_work_chapters = self.full_work_soup.find_all('div',{'id':re.compile('chapter-\d+')})
+                if len(self.full_work_chapters) != self.num_chapters():
+                    ## sanity check just in case.
+                    self.use_full_work_soup = False
+                    self.full_work_soup = None
+                    logger.warn("chapter count in view_full_work(%s) disagrees with num of chapters(%s)--ending use_view_full_work"%(len(self.full_work_chapters),self.num_chapters()))
             whole_dl_soup = self.full_work_soup
-            chapter_dl_soup = whole_dl_soup.find('div',{'id':'chapter-%s'%(index+1)})
-            if not chapter_dl_soup:
-                self.use_full_work_soup = False
-                logger.warn("chapter-%s not found in view_full_work--ending use_view_full_work"%(index+1))
-        if not chapter_dl_soup:
-            whole_dl_soup = chapter_dl_soup = self.make_soup(self._fetchUrl(url))
+
+        if whole_dl_soup:
+            chapter_dl_soup = self.full_work_chapters[index]
+        else:
+            whole_dl_soup = chapter_dl_soup = self.make_soup(self._fetchUrl(url+self.addurl))
             if None == chapter_dl_soup:
                 raise exceptions.FailedToDownload("Error downloading Chapter: %s!  Missing required element!" % url)
 
