@@ -67,6 +67,8 @@ class HarryPotterFanFictionComSiteAdapter(BaseSiteAdapter):
     def extractChapterUrlsAndMetadata(self):
 
         url = self.url
+        if self.is_adult or self.getConfig("is_adult"):
+            url = url+'&showRestricted'
         logger.debug("URL: "+url)
 
         try:
@@ -77,6 +79,9 @@ class HarryPotterFanFictionComSiteAdapter(BaseSiteAdapter):
             else:
                 raise e
 
+        if "This story may contain chapters not appropriate for a general audience." in data and not (self.is_adult or self.getConfig("is_adult")):
+            raise exceptions.AdultCheckRequired(self.url)
+
         ## Don't know if these still apply
         # if "Access denied. This story has not been validated by the adminstrators of this site." in data:
         #     raise exceptions.AccessDenied(self.getSiteDomain() +" says: Access denied. This story has not been validated by the adminstrators of this site.")
@@ -90,11 +95,6 @@ class HarryPotterFanFictionComSiteAdapter(BaseSiteAdapter):
         h2 = soup.find('h2')
         h2.find('i').extract() # remove author
         self.story.setMetadata('title',stripHTML(h2))
-        ## Don't know if these still apply
-        ## javascript:if (confirm('Please note. This story may contain adult themes. By clicking here you are stating that you are over 17. Click cancel if you do not meet this requirement.')) location = '?psid=290995'
-        # if "This story may contain adult themes." in a['href'] and not (self.is_adult or self.getConfig("is_adult")):
-        #     raise exceptions.AdultCheckRequired(self.url)
-
 
         # Find authorid and URL from... author url.
         a = soup.find('a', href=re.compile(r"viewuser.php\?uid=\d+"))
@@ -118,9 +118,11 @@ class HarryPotterFanFictionComSiteAdapter(BaseSiteAdapter):
         # fetch author page to get story description.
         authorsoup = self.make_soup(self._fetchUrl(self.story.getMetadata('authorUrl')))
 
-        # assumes don't need to worry about story URLs in descs.
-        storya = authorsoup.find('a', href=re.compile(r"^/viewstory.php\?psid="+self.story.getMetadata('storyId')))
-        storydiv = storya.find_parent('div')
+        for story in authorsoup.find_all('article',class_='story-summary'):
+            storya = story.find('h3').find('a',href=re.compile(r"^/viewstory.php\?psid="+self.story.getMetadata('storyId')))
+            if storya:
+                storydiv = storya.find_parent('div')
+                break
 
         # desc is escaped html in attr on iframe.
         iframe = storydiv.find('iframe')
