@@ -323,6 +323,7 @@ def get_valid_keywords():
     return list(['(in|ex)clude_metadata_(pre|post)',
                  'add_chapter_numbers',
                  'add_genre_when_multi_category',
+                 'add_category_when_multi_category',
                  'adult_ratings',
                  'allow_unsafe_filename',
                  'always_overwrite',
@@ -411,6 +412,7 @@ def get_valid_keywords():
                  'max_fg_sleep_at_downloads',
                  'min_fg_sleep',
                  'never_make_cover',
+                 'cover_min_size',
                  'no_image_processing',
                  'non_breaking_spaces',
                  'download_text_version',
