@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2011 Fanficdownloader team, 2018 FanFicFare team
+# Copyright 2011 Fanficdownloader team, 2020 FanFicFare team
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -56,9 +56,14 @@ imagetypes = {
 
 try:
     from calibre.utils.magick import Image
-    from .six import BytesIO
     convtype = {'jpg':'JPG', 'png':'PNG'}
 
+    def get_image_size(data):
+        img = Image()
+        img.load(data)
+        owidth, oheight = img.size
+        return owidth, oheight
+
     def convert_image(url,data,sizes,grayscale,
                       removetrans,imgtype="jpg",background='#ffffff'):
         # logger.debug("calibre convert_image called")
@@ -104,6 +109,12 @@ except:
         from PIL import Image
         from .six import BytesIO
         convtype = {'jpg':'JPEG', 'png':'PNG'}
+
+        def get_image_size(data):
+            img = Image.open(BytesIO(data))
+            owidth, oheight = img.size
+            return owidth, oheight
+
         def convert_image(url,data,sizes,grayscale,
                           removetrans,imgtype="jpg",background='#ffffff'):
             # logger.debug("Pillow convert_image called")
@@ -980,6 +991,20 @@ class Story(Configurable):
                         retlist = newretlist
                         ## logger.debug(retlist)
 
+            ## Add value of add_genre_when_multi_category to genre if
+            ## there's more than one category value.  Does not work
+            ## consistently well if you try to include_in_ chain genre
+            ## back into category--breaks with fandoms sites like AO3
+            if listname == 'genre' and self.getConfig('add_genre_when_multi_category') and len(self.getList('category',
+                                                                                                            removeallentities=False,
+                                                                                                            # to avoid inf loops if genre/cat substs
+                                                                                                            includelist=includelist+[listname],
+                                                                                                            doreplacements=False,
+                                                                                                            skip_cache=True,
+                                                                                                            seen_list=seen_list
+                                                                                                            )) > 1:
+                retlist.append(self.getConfig('add_genre_when_multi_category'))
+
             if retlist:
                 if doreplacements:
                     newretlist = []
@@ -993,14 +1018,6 @@ class Story(Configurable):
 
                 retlist = [x for x in retlist if x!=None and x!='']
 
-            if listname == 'genre' and self.getConfig('add_genre_when_multi_category') and len(self.getList('category',
-                                                                                                            removeallentities=False,
-                                                                                                            # to avoid inf loops if genre/cat substs
-                                                                                                            doreplacements=False,
-                                                                                                            seen_list=seen_list
-                                                                                                            )) > 1:
-                retlist.append(self.getConfig('add_genre_when_multi_category'))
-
             if retlist:
                 if listname in ('author','authorUrl','authorId') or self.getConfig('keep_in_order_'+listname):
                     # need to retain order for author & authorUrl so the
@@ -1009,6 +1026,16 @@ class Story(Configurable):
                 else:
                     # remove dups and sort.
                     retlist = sorted(list(set(retlist)))
+
+                    ## Add value of add_genre_when_multi_category to
+                    ## category if there's more than one category
+                    ## value (before this, obviously).  Applied
+                    ## *after* doReplacements.  For normalization
+                    ## crusaders who want Crossover as a category
+                    ## instead of genre.  Moved after dedup'ing so
+                    ## consolidated category values don't count.
+                    if listname == 'category' and self.getConfig('add_category_when_multi_category') and len(retlist) > 1:
+                        retlist.append(self.getConfig('add_category_when_multi_category'))
             else:
                 retlist = []
 
@@ -1242,8 +1269,18 @@ class Story(Configurable):
                     logger.info("Failed to load or convert image, \nparent:%s\nskipping:%s\n(Exception output also caused exception)"%(parenturl,imgurl))
                 return ("failedtoload","failedtoload")
 
+            cover_big_enough = True
+            try:
+                sizes = [ int(x) for x in self.getConfigList('cover_min_size') ]
+                if sizes:
+                    owidth, oheight = get_image_size(data)
+                    cover_big_enough = owidth >= sizes[0] and oheight >= sizes[1]
+                    logger.debug("cover_big_enough:%s %s>=%s, %s>=%s"%(cover_big_enough,owidth,sizes[0],oheight,sizes[1]))
+            except Exception as e:
+                raise exceptions.FailedToDownload("Failed to process cover_min_size from personal.ini:%s\nException: %s"%(self.getConfigList('cover_min_size'),e))
+
             # explicit cover, make the first image.
-            if cover:
+            if cover and cover_big_enough:
                 if len(self.imgtuples) > 0 and 'cover' in self.imgtuples[0]['newsrc']:
                     # remove existing cover, if there is one.
                     del self.imgurls[0]
@@ -1263,7 +1300,8 @@ class Story(Configurable):
                 if self.cover == None and \
                         self.getConfig('make_firstimage_cover') and \
                         not self.getConfig('never_make_cover') and \
-                        not (coverexclusion and re.search(coverexclusion,imgurl)):
+                        not (coverexclusion and re.search(coverexclusion,imgurl)) and \
+                        cover_big_enough:
                     newsrc = "images/cover.%s"%ext
                     self.cover=newsrc
                     self.setMetadata('cover_image','first')
